/*******************************************************************************

	Decomposition of individual growth rates into macro/sector/firm effects

********************************************************************************/

/****************************************************************************
	Date: July, 2013. Last update April 2014
	
	Program: microestimation
	
	This file:
	- Starts from $data.dta
	- Runs the variance decomposition at the individual level for different specifications
		1) gr_capays on FE
		2) gr_capays on FE and FE interacted with controls
		3) gr_vapays on FE
		4) gr_capays on FE (sector*destination + local market)
	- Uses the following programs (saved in $dopath):
	    1) growth_regs.do (FE regression for a single country * year)
		2) threesteps_growth_regs.do (Runs FE regression, store results and decompose firm component into firm-common and firm-destination)
	    3) interacted_growth_regs.do (Runs FE regression with firm-specific controls, for a single country * year and decompose firm-component into firm-common and firm-destination)) 
		4) microresults_firststep.do (Compute statistics in Tables 2 and 3)
		5) microresults_secondstep.do (Compute statistics in Table 4)
		6) growth_regs_localef.do (FE regression with destination*sector + local market effects)
		7) threesteps_growth_regs_localef.do (Runs FE regression with destination*sector + local market effects, store results and decompose firm component)
	
	Inputs: 
	- working paths
	- name of the log file
	- time period (first and last years) 
	- macro variables:
		"data" name of the dataset
		"samplename" used to name output files (either mfg for the manufactuyring sector or all for the whole economy)
	    "variable" the variable of interest (either capays in the benchmark case or vapays in the robustness)
		"refsect" the reference sector in fixed effect regressions
		"sect" the name of the variable identifying sectors
		"controls" the set of firm-level variable used as control in robustness checks. 
	
	 $data must contain the following variables 
	- year: time identifier
	- siren: firm identifier
	- $sect: sector identifier
	- pays: destination country identifier
	- gr_capays and gr_vapays: annual growth rate of sales and value added, by firm*destination*year
	- capays and vapays: current value of market-specific sales and value added
	- lag_capays and lag_vapays: lagged value of market-specific sales and value added
	- firm-level control variables used to obtain results in Table A.2: size, age, RDint (RD expenses over sales), patent (patenting expenses over sales)
		openness (export/total sales) and totdebtratio (total debt over value added)	
	- out_gr: A dummy equal to one if the growth rate falls into the category of "outliers" and is thus neglected from the micro-level estimation
	- ze: local market identifier
	
	Output:
	- Datasets with estimated components of individual growth rates:
		1) $outputpath/growth_regs_capays_$samplename
		2) $outputpath/growth_`control'_interacted_regs_capays_$samplename for each `control' in $controls
		3) $outputpath/growth_localFE_regs_capays_$samplename
		4) $outputpath/growth_regs_vapays_$samplename
		
	
****************************************************************************/

clear
set matsize 10000

*** Define working path 
global dopath W:\Granularity\DoFiles\ECMA
global datapath E:\temp\MEJEAN\dGLM
global outputpath E:\temp\MEJEAN\dGLM\Output

*** Define time span
global firstyear = "1990"
global lastyear = "2007"
global secondyear = $firstyear + 1
global thirdyear = $secondyear + 1

*** Define the dataset/sample/variable to work on
global data = "temp_mfg_capays"
global samplename="mfg" 
global variable capays
global refsect = "23"
global sect = "naf60"
global controls = "pct_size classage RD pat openness pct_totdebt"

log using $outputpath\microestimation_$samplename, text replace

*** Load in do files run later on
cd "$dopath"
quietly do growth_regs
quietly do growth_reg_localef
quietly do threesteps_growth_regs
quietly do threesteps_growth_regs_localef
quietly do interacted_growth_regs
quietly do microresults_firststep
quietly do microresults_secondstep

*** Upload data and keep observations used for identification
cd $datapath
use $data, clear
drop if out_gr==1
keep if gr_$variable~=.

egen id_p=group(pays)
egen id_fp=group(siren pays)

*** summary statistics on individual growth rates, by year
table year if year>$firstyear, c(m gr_$variable sd gr_$variable count gr_$variable)

*** compute weights
egen tot_$variable = sum(lag_$variable), by(year)
ge w_fn = lag_$variable/tot_$variable
label var w_fn "weight of firm*destination in total $variable"

*** construct firm-level variables used as controls in robustness checks
*** size log and percentiles
ge log_size = log(size)
foreach X of numlist 20(20)80{
	egen p`X' = pctile(log_size), p(`X') by(year)
}
ge pct_size = 1 if log_size<p20
replace pct_size = 2 if log_size>=p20 & log_size<p40
replace pct_size = 3 if log_size>=p40 & log_size<p60
replace pct_size = 4 if log_size>=p60 & log_size<p80
replace pct_size = 5 if log_size>=p80 
drop p20 p40 p60 p80

*** age: log and class
ge log_age=log(age+1)
ge classage=0 if age<=5
replace classage=1 if age>5

*** RD intensity: a dummy for whether R&D expenses are higher than 1% of value added
bysort siren year: gen _=RDint if _n==1
bysort siren: egen meanRDint=mean(_)
drop _
replace meanRDint=. if RDint==.
gen RD=0
replace RD=1 if meanRDint>0.01
drop RDint meanRDint 

*** patenting intensity: a dummy for whether patent expenses are higher than 5% of value added
bysort siren year: gen _=patent if _n==1
bysort siren: egen meanpatint=mean(_)
drop _
replace meanpatint=. if meanpatint==.
gen pat=0
replace pat=1 if meanpatint>0.05
drop patent meanpatint

*** Debt to sales ratio
g ltotdebtratio=log(totdebtratio)
foreach X of numlist 20(20)80{
	egen p`X' = pctile(totdebtratio), p(`X') by(year)
}
ge pct_totdebt = 1 if totdebtratio<p20
replace pct_totdebt = 2 if totdebtratio>=p20 & totdebtratio<p40
replace pct_totdebt = 3 if totdebtratio>=p40 & totdebtratio<p60
replace pct_totdebt = 4 if totdebtratio>=p60 & totdebtratio<p80
replace pct_totdebt = 5 if totdebtratio>=p80 
drop p20 p40 p60 p80

save $datapath/tempdmg, replace

* correlation between all the firm-specific variables
corr log_size pct_size log_age classage RD pat openness ltotdebtratio pct_totdebt 



*** Estimation without any control variables on level growth rates (Benchmark results in Tables 2, 3, 4, 5 and Figure 3)
di "Benchmark estimation: Total sales $samplename"
threesteps_growth_regs $datapath/tempdmg gr_$variable $outputpath/growth_regs_capays_$samplename
sum gr_idio Rsquared

*** Summary statistics on the benchmark micro-level decomposition (Tables 2, 3, 4 in the paper)
di "Summary statistics on firm-destination growth rates and components: Total sales $samplename"
microresults_firststep $outputpath/growth_regs_capays_$samplename 0 gr_$variable
microresults_secondstep $outputpath/growth_regs_capays_$samplename 0 gr_$variable
di "Summary statistics on firm-destination growth rates and components: Domestic sales $samplename"
use $outputpath/growth_regs_capays_$samplename, clear
keep if pays=="FR"
save temp, replace
microresults_firststep temp 0 gr_$variable
microresults_secondstep temp 0 gr_$variable
di "Summary statistics on firm-destination growth rates and components: Export sales $samplename"
use $outputpath/growth_regs_capays_$samplename, clear
keep if pays!="FR"
save temp, replace
microresults_firststep temp 0 gr_$variable
microresults_secondstep temp 0 gr_$variable

*** Estimation on level growth rates, with sectoral fixed effects interacted with firm-specific variables (Table A2)
foreach control in $controls{
	di "Estimation with firm-level controls: Controlling for `control' $samplename"
	interacted_growth_regs $datapath/tempdmg $sect $refsect gr_$variable `control' $outputpath/growth_`control'_interacted_regs_capays_$samplename
	sum gr_idio Rsquared
}


*** Estimation on level growth rates using additional local market fixed effects
* note this imposes additional constraints on the number of obs per local market and thus the sample is reduced
use $datapath/$data, clear

keep if gr_$variable!=.
drop if out_gr==1
keep if ze!=.

bysort pays year ze: egen count=count($variable)
drop if count==1
keep if pays=="AT"|pays=="BE"|pays=="CA"|pays=="DE"|pays=="DK"|pays=="ES"|pays=="FR"|pays=="GB"|pays=="GR"|pays=="IE"|pays=="IT"|pays=="JP"|pays=="MA"|pays=="NL"|pays=="PT"|pays=="SE"|pays=="TN"|pays=="US"

egen tot_$variable = sum(lag_$variable), by(year)
ge w_fn = lag_$variable/tot_$variable

egen id_z=group(ze)
egen id_p=group(pays)
egen id_fp=group(siren pays)

save $datapath/tempdmg, replace

di "Estimation with additional local market effects: Total sales $samplename"
threesteps_growth_regs_localef $datapath/tempdmg gr_$variable $outputpath/growth_localFE_regs_capays_$samplename


*** Estimation on level growth rates using value added instead of sales as LHS variable (Panel IV of Table 5)
global data = "temp_mfg_vapays"
global variable vapays

cd $datapath
use $data, clear
drop if out_gr==1
keep if gr_$variable~=.

egen id_p=group(pays)
egen id_fp=group(siren pays)

egen tot_$variable = sum(lag_$variable), by(year)
ge w_fn = lag_$variable/tot_$variable
label var w_fn "weight of firm*destination in total $variable"
save $datapath/tempdmg, replace

di "Benchmark estimation using value added as LHS variable, $samplename"
threesteps_growth_regs $datapath/tempdmg gr_$variable $outputpath/growth_regs_vapays_$samplename
sum gr_idio Rsquared

* erase temporary files
erase $datapath/tempdmg.dta
erase $datapath/temp.dta

log close
