function [VAR COV COV_B VAR_TOTAL SD_TOTAL VAR_ONLY SD_ONLY COV_W] = var_growth_cs(id1,id2,year,X,w)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function creates firm-level variances with and across groups, such
% as sectors or destinations. As such, two ids are needed:
%
%   id1: the firm (or firm destination) id
%   id2: the group id (e.g., sector)
%
% There are three components that need to be created:
%   1. Variances of firms within groups: VAR
%   2. Covariances of firms within groups: VAR
%   3. Covariances of firms across groups: COV
%
% The VAR_TOTAL = (1 & 2) + 3
%
% Furthermore, this file will also back on the VAR_ONLY component, which
% will be sub-part of the VAR component.
%
% We also create all bilatreal (i,j) covarainces in COV_B
%
% The linear algebra is based on var_growth.m and var_only_growth.m, but
% now we have to create dummy matrices, based on group id's to pre-multiply
% the weights of the firms. This will be by loops, and the finaly matrices
% (VAR, COV, etc), will only take the diagonal elements (the off-diagonal
% capures correlations across time), so the nomenclature for the matrices
% are slightly different than the previous files.
%
% The final matrices will be (T*G), where G = number of groups, and T is
% the number of time periods.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% From before and needed for 1, 2, and 3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create a balanced matrix of growth rates, where 0's fill in missing,
% which is ok b/c will sum over zeros and not count when taking averages

[h1,h2,ii]=unique(id1);
[h1,h2,jj]=unique(year);

N=max(ii);
T=max(jj);

bigX=zeros(N,T);
bigX(sub2ind([N T],ii,jj))= X;

bigO=zeros(N,T);
bigO(sub2ind([N T],ii,jj))=1;
counts=sum(bigO,2);
mX=sum(bigX,2)./sum(bigO,2);
demeanX=(bigX-repmat(mX,1,T)).*bigO;

% Demeaned matrix which is N,T and create a (T_n - 1) to divide by 

Y = reshape(demeanX,N,T);

t = counts - ones(size(counts,1),1);
tt = repmat(t,1,T);
TT = reshape(tt,N,T);

Y = Y./sqrt(TT);

% Get weights aligned correctly

W = zeros(N,T);
W(sub2ind([N T],ii,jj))=w;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% NEW: for group analysis and looping
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create a balanced matrix for group id's

G = zeros(N,T);
G(sub2ind([N T],ii,jj)) = id2;

g_min = min(id2);
g_max = max(id2);

VAR = zeros(T,g_max);
COV = zeros(T,g_max);
COV_B = zeros(T,g_max*g_max);
VAR_TOTAL = zeros(T,g_max);
SD_TOTAL = zeros(T,g_max);
VAR_ONLY = zeros(T,g_max);
SD_ONLY = zeros(T,g_max);

for i = g_min:g_max
    D1 = (G==i);            % Within group dummy
    W1 = D1.*W;

    % 1. Create the VAR component
    
    var = (W1'*Y)*(Y'*W1);
    VAR(:,i) = diag(var);
    
    % 2. Create the COV component

    cov = zeros(T,T);
    cov_b = zeros(T,g_max);
    k1 = g_max*(i-1) + 1;
    k2 = i*g_max;
    for j = g_min:g_max
        if j~=i
            D2 = (G==j);            % Outide group dummy
            W2 = D2.*W;
            c = (W1'*Y)*(Y'*W2);
            cov = cov + c;
            cov_b(:,j) = diag(c);
            clear c;
        end
    end
    COV(:,i) = diag(cov);
    COV_B(1:T,k1:k2) = cov_b;
    
    % 3. Create the VAR_TOTAL component
    
    var_total = var + cov;
    VAR_TOTAL(:,i) = diag(var_total);
        
    clear var cov cov_b var_total;
    
    % 4. Create var_only
    
    y = W1.*W1.*repmat(sum(Y.*Y,2),1,T);
    VAR_ONLY(:,i) =sum(y,1);
    
    clear y;
end

SD_TOTAL = sqrt(VAR_TOTAL);
SD_ONLY = sqrt(VAR_ONLY);

COV_W = VAR - VAR_ONLY;

for i = g_min:g_max
k = (i-1)*g_max + i;
COV_B(:,k) = COV_W(:,i);
end
